PyXMake Developer Guide: PyXMake.VTL.ssh_f2py Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.VTL.ssh_f2py Namespace Reference

## Functions
| main (BuildID, user, key, files=VTL.GetSourceCode(0), command=VTL.GetBuildCommand(4), lib=VTL.GetLinkDependency(0, 4,"x64"), source=os.path.join(__mcd_core_path,"src"), include=[posixpath.join(__mcd_cluster_incpath, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, "x64")], dependency=posixpath.join(__mcd_cluster_stable,"lib"), output=posixpath.join(__mcd_cluster_dev,"bin"), environment=VTL.GetEnvironment(2), architecture="x64", scratch=VTL.Scratch, verbosity=2, incremental=False, host="129.247.54.37", port=22, **kwargs)

## Variables
| parser = argparse.ArgumentParser(description="Build shared Fortran libraries for Python remotely on the institute cluster.")
| metavar
| nargs
| help
| _ = sys.argv[1]
| args
| user = args.user[0]
| key = args.key[0]
str | BuildID = VTL.GetEnvironment(i)
| files = VTL.GetBuildCommand(4,"free")
list | lib = []
| source = os.path.join(__mcd_core_path,"external","beos")
| command
| include
| dependency
| environment
| env
| verbosity
| incremental

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile Fortran source for PYTHON remotely
                 on the institute cluster. Uses main function.

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake
          - SSH key

    @date:
          - 24.07.2019

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.ssh_f2py.main | ( |  | BuildID,
|  |  | user,
|  |  | key,
|  |  | files = VTL.GetSourceCode(0),
|  |  | command = VTL.GetBuildCommand(4),
|  |  | lib = VTL.GetLinkDependency(0, 4,"x64"),
|  |  | source = os.path.join(__mcd_core_path,"src"),
|  |  | include = [posixpath.join(__mcd_cluster_incpath, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, "x64")],
|  |  | dependency = posixpath.join(__mcd_cluster_stable,"lib"),
|  |  | output = posixpath.join(__mcd_cluster_dev,"bin"),
|  |  | environment = VTL.GetEnvironment(2),
|  |  | architecture = "x64",
|  |  | scratch = VTL.Scratch,
|  |  | verbosity = 2,
|  |  | incremental = False,
|  |  | host = "129.247.54.37",
|  |  | port = 22,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 57 of file ssh_f2py.py.

## Variable Documentation

## ◆ _

PyXMake.VTL.ssh_f2py._ = sys.argv[1]
| protected

Definition at line 111 of file ssh_f2py.py.

## ◆ args

PyXMake.VTL.ssh_f2py.args

Definition at line 112 of file ssh_f2py.py.

## ◆ BuildID

str PyXMake.VTL.ssh_f2py.BuildID = VTL.GetEnvironment(i)

Definition at line 127 of file ssh_f2py.py.

## ◆ command

PyXMake.VTL.ssh_f2py.command

Definition at line 133 of file ssh_f2py.py.

## ◆ dependency

PyXMake.VTL.ssh_f2py.dependency

Definition at line 133 of file ssh_f2py.py.

## ◆ env

PyXMake.VTL.ssh_f2py.env

Definition at line 133 of file ssh_f2py.py.

## ◆ environment

PyXMake.VTL.ssh_f2py.environment

Definition at line 133 of file ssh_f2py.py.

## ◆ files

PyXMake.VTL.ssh_f2py.files = VTL.GetBuildCommand(4,"free")

Definition at line 128 of file ssh_f2py.py.

## ◆ help

PyXMake.VTL.ssh_f2py.help

Definition at line 107 of file ssh_f2py.py.

## ◆ include

PyXMake.VTL.ssh_f2py.include

Definition at line 133 of file ssh_f2py.py.

## ◆ incremental

PyXMake.VTL.ssh_f2py.incremental

Definition at line 133 of file ssh_f2py.py.

## ◆ key

PyXMake.VTL.ssh_f2py.key = args.key[0]

Definition at line 119 of file ssh_f2py.py.

## ◆ lib

list PyXMake.VTL.ssh_f2py.lib = []

Definition at line 129 of file ssh_f2py.py.

## ◆ metavar

PyXMake.VTL.ssh_f2py.metavar

Definition at line 107 of file ssh_f2py.py.

## ◆ nargs

PyXMake.VTL.ssh_f2py.nargs

Definition at line 107 of file ssh_f2py.py.

## ◆ parser

PyXMake.VTL.ssh_f2py.parser = argparse.ArgumentParser(description="Build shared Fortran libraries for Python remotely on the institute cluster.")

Definition at line 106 of file ssh_f2py.py.

## ◆ source

PyXMake.VTL.ssh_f2py.source = os.path.join(__mcd_core_path,"external","beos")

Definition at line 131 of file ssh_f2py.py.

## ◆ user

PyXMake.VTL.ssh_f2py.user = args.user[0]

Definition at line 118 of file ssh_f2py.py.

## ◆ verbosity

PyXMake.VTL.ssh_f2py.verbosity

Definition at line 133 of file ssh_f2py.py.